@@ -4,7 +4,7 @@
 
     The default highlighting style.
 
-    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2025 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -13,13 +13,16 @@ from pygments.token import Keyword, Name, Comment, String, Error, \
      Number, Operator, Generic, Whitespace
 
 
+__all__ = ['DefaultStyle']
+
+
 class DefaultStyle(Style):
     """
     The default style (inspired by Emacs 22).
     """
+    name = 'default'
 
     background_color = "#f8f8f8"
-    default_style = ""
 
     styles = {
         Whitespace:                "#bbbbbb",
@@ -64,6 +67,7 @@ class DefaultStyle(Style):
         Generic.Error:             "#E40000",
         Generic.Emph:              "italic",
         Generic.Strong:            "bold",
+        Generic.EmphStrong:        "bold italic",
         Generic.Prompt:            "bold #000080",
         Generic.Output:            "#717171",
         Generic.Traceback:         "#04D",
